function chain = allfeature(Pgray, asHistogram, numbins)
% This function calculates a color feature out of a color patch P.
% The patch is resized to a 5x5 image and used as feature,
% resulting in a 25 bin sized feature.
%
% P: A gray patch
%
% asHistogram: if false, the feature is returned directly. 
% If true, a histogram of it is returned.
% 
% numbins: Number of bins for the histogram. Only needed if asHistogram
% is true.

try
    P = imresize(Pgray, [5 5]);
    chain = double(P(:)');
catch exception
    chain = zeros(1, 25);
end;

if (asHistogram)
    chain = hist(chain, numbins);
end;
