function [errors] = classifier_svm(M, y, n, svm_options) 

if nargin < 4
    svm_options = '';
end

reset(RandStream.getDefaultStream());

% scale M
M = zscore(M); % to scale

%% perform CV
errors = zeros(1,n);
for i = 1:n,
    ind_train = randsample(length(y), length(y), true);
    ind_test = 1:length(y);
    ind_test(unique(ind_train)) = [];
    
    % train and test with built-in kernel
    libSVMStruct = svmtrain(y(ind_train), M(ind_train,:), svm_options);
    ygt = y(ind_test); % y ground truth
    [predicted_labels, accuracy, decision_values] = svmpredict(ygt, M(ind_test,:), libSVMStruct);
    error = 1-accuracy(1)/100;
    ygt = y(ind_test)'; % y ground truth
    errors(i) = error;
    
    % confusion matrices per patient
    %ygt(ygt==min(ygt)) = 0;
    %ygt(ygt==max(ygt)) = 1;
    %predicted_labels(predicted_labels==min(predicted_labels)) = 0;
    %predicted_labels(predicted_labels==max(predicted_labels)) = 1;
    %disp(ygt);
    %disp(predicted_labels');
    %[c,cm,ind,per] = confusion(ygt, predicted_labels');
    %disp(cm);
end;

