function chain = colorfeature(P, asHistogram, numbins)
% This function calculates a color feature out of a color patch P.
% Each color channel is resized to a 5x5 image and used as feature,
% resulting in a concatenated 75 bin sized feature.
%
% P: A colored patch
%
% asHistogram: if false, the feature is returned directly. 
% If true, a histogram of it is returned.
% 
% numbins: Number of bins for the histogram. Only needed if asHistogram
% is true.

try
    R = imresize(P(:,:,1), [5 5]);
    G = imresize(P(:,:,2), [5 5]);
    B = imresize(P(:,:,3), [5 5]);
    
    chain = double([R(:)' G(:)' B(:)']);
catch exception
    chain = zeros(1, 75);
end;

if (asHistogram)
    chain = hist(chain, numbins);
end;
