function [rect isStained] = makePatch(I, imgfilename, mid_x, mid_y, patch_size, patch_foldername, patch_filename, plot_flag)
% This function makes one patch out of an image and stores it
%
% imgfilename: The original image, a TIF file
% mid_x: For the midpoint of the patch
% mid_y: For the midpoint of the patch
% patch_size = The size of one side in pixels (it will be a square)
% patch_foldername = The foldername where the patch should be stored
% patch_filename = The filename of the patch
% plot_flag = If true, patches are stored as images in patch_foldername.
%I = imread(imgfilename, 'tiff');
info = imfinfo(imgfilename, 'tiff');

%if (size(I, 3)>3)
%    I = I(:,:,1:3);
%end;

rect = []; 
isStained = [];

% adjust image
%I(:,:,1) = imadjust(I(:,:,1));
%I(:,:,2) = imadjust(I(:,:,2));
%I(:,:,3) = imadjust(I(:,:,3));

% define the patch area
w = patch_size;
h = patch_size;
wdiv2 = floor(w/2);
hdiv2 = floor(h/2);
xmin = mid_x - wdiv2;
ymin = mid_y - hdiv2;

%xmin = max(0, xmin);
%ymin = max(0, ymin);
%w = min(w, info.Width-xmin);
%h = min(h, info.Height-ymin);       
if (xmin >= 0 && ymin >= 0 && xmin+w <= info.Width && ymin+h <= info.Height)
    % crop the image (Patch)
    rect = [xmin, ymin, w-1, h-1];
    P = imcrop(I, rect);
    
    % decide whether P is stained or not
    isStained = isstained(P);
    if (isStained)
        stained_tag = '_stained_1';
    else
        stained_tag = '_stained_0';
    end;
    
    % save the copped image
    if (plot_flag)
        imwrite(P, strcat(patch_foldername, patch_filename, stained_tag, '.tif'), 'TIFF');        
    end;
end;

end