function featurevector = patch2features(P, S, method, normalize_histograms)
% This function extracts all features out of a given Patch.
%
% P: the RGB Patch
% S: the black white shape
% 

if size(P,3)==1
    Pgray = P;
else
    Pgray = rgb2gray(P);
end;

%disp(class(P));
%disp(min(P(:)));
%disp(max(P(:)));
%disp(class(S));
%disp(min(S(:)));
%disp(max(S(:)));
%disp(class(Pgray));
%disp(min(Pgray(:)));
%disp(max(Pgray(:)));


featurevector = [];
% append feature 'hist_all'
if (strcmp(method,'hist_all'))
    h = allfeature(Pgray, false, 0);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h]; %#ok<*AGROW>
end;
% append feature 'hist_fg'
if (strcmp(method,'hist_fg'))
    h = imhist(Pgray(S~=0), 16)';
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h]; %#ok<*AGROW>
end;
% append feature 'hist_bg'
if (strcmp(method,'hist_bg'))
    h = imhist(Pgray(S==0), 16)';
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end;
% append shape features regionprops
if (strcmp(method,'prop') || strcmp(method,'shape'))
    STATS = regionprops(S,Pgray,'all');
    try 
        featurevector = [featurevector ...
        double(STATS.Area) ...
        double(STATS.BoundingBox(3:4)) ...
        double(STATS.MajorAxisLength) ...
        double(STATS.MinorAxisLength) ...
        double(STATS.Eccentricity) ...
        double(STATS.ConvexArea) ...
        double(STATS.EquivDiameter) ...
        double(STATS.Solidity) ...
        double(STATS.Extent) ...
        double(STATS.Perimeter) ...
        double(STATS.MeanIntensity) ...
        double(STATS.MinIntensity) ...
        double(STATS.MaxIntensity)];
    catch exception
        featurevector = [featurevector zeros(1, 14)];
    end;
end;

% append feature 'lbp' (Local Binary Pattern)
if (strcmp(method,'hist_lbp'))
    h = lbp(Pgray, false, 0);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end;

% append feature 'col' (Color Feature)
if (strcmp(method,'hist_col'))
    h = colorfeature(P, false, 0);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end;

% shapes
% append feature 'fcc' (Freeman Chain Code)
if (strcmp(method,'hist_fcc'))
    h = fcc(S, true, 8);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end;
% append feature 'sig' (1D-signature)
if (strcmp(method,'hist_sig'))
    h = sig(S, true, 16);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end;
% append feature 'phog' (PHOG)
if (strcmp(method,'hist_phog'))
    h = phog(Pgray, false, 8);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end;
% append feature 'sift' (SIFT)
if (strcmp(method,'hist_sift'))
    h = siftfeature(Pgray, false, 0);
    if (normalize_histograms)
        h = normv(h);
    end;
    featurevector = [featurevector h];
end; 
end