function code = phog(S, asHistogram, numbins)
% This function calculates the phog descriptor of a given shape S.
% Descriptor is calculated according to Anna Bosch and Andrew Zisserman.
% http://www.robots.ox.ac.uk/~vgg/research/caltech/phog.html
% 
% S: An image, 0 for background
%
% asHistogram: not used. PHOG is always a histogram descriptor
% 
% numbins: Number of bins for the histogram. If 0, it is set to 8.
%

if (max(max(S))<1) % if there is no patch
    code = zeros(1,168);
else
    try
        % rotate the image to have x axis the highest expansion of the shape
        %[L, num] = bwlabel(S, 8);
        %s = diameter(L);
        %S = logical(S);
        %[B, theta] = x2majoraxis(s.MajorAxis, S);

        % get the boundaries of the connected component (of the biggest conn comp)
        %B = boundaries(B);
        %d = cellfun('length', B);
        %[max_d, k] = max(d);
        %b = B{k};

        % calculate the phog signature
        if (numbins==0)
          numbins = 8;
        end;
        angle = 360;
        L=2;
        roi = [1;size(S,1);1;size(S,2)];
        code = anna_phog(S,numbins,angle,L,roi)';

    catch exception
        code = zeros(1,168);
    end;
end;

% calculate the histogram over the signature
if (asHistogram)
    %code = hist(code, numbins);
    code = code;
end;