function visualize_prediction(imagefile, labelfile, Y_hat_new)
% This function opens two corresponding images from pathologist1,
% screens all the spots, finds corresponding spots
% and makes the patches out of the corresponding cell nuclei, if it is
% detected from both pathologists.
%
% All four images have to exist:
% path1_image.TIF
% path1_image.svg
%
% path1_image_foldername: Foldername of the images of Pathologist 1
% imgname: Image names without ending. Must be equal for both pathologists.
%
%
% 

percentage_samples = 100; % consider x% of the labeled samples
reset(RandStream.getDefaultStream());

path1_image_foldername = '';
patch_foldername = '';
patch_size = 80;
    
img_files = dir(imagefile);
lab_files = dir(labelfile);

outmatrix = [];
for k = 1:length(img_files)
    I = imread([path1_image_foldername, img_files(k).name], 'tiff');
    J = I;
    if (size(I, 3)>3)
        I = I(:,:,1:3);
    end;
    % adjust image
    I(:,:,1) = imadjust(I(:,:,1));
    I(:,:,2) = imadjust(I(:,:,2));
    I(:,:,3) = imadjust(I(:,:,3));

    imgname = img_files(k).name;
    imgname((end-4):end) = [];

    p1_labelfilename = strcat(path1_image_foldername, lab_files(k).name);
    p1_imgfilename = strcat(path1_image_foldername, img_files(k).name);
    p1_objects = read_svg(p1_labelfilename);
    p1_labels = [p1_objects.title];
    p1_polygons = {p1_objects.points};
    p1_midpoints = {};
    p1_radii = [];
    d_p1 = 0;
    for i = 1:length(p1_objects),
        xs = p1_polygons{i}(1,:);
        ys = p1_polygons{i}(2,:);
        xmin = min(xs);
        ymin = min(ys);
        w = max(xs) - xmin;
        h = max(ys) - ymin;
        d_p1 = d_p1 + (w+h)/2;

        p1_midpoints{i} = {round(xmin+w/2), round(ymin+h/2)};
        p1_radii(i) = (w+h)/4;
    end;
    %d_p1 = d_p1/length(p1_objects);
    %disp(d_p1);
    %disp(length(p1_objects));

    numlabels = size(p1_objects, 2);

    hI = 1:size(p1_objects, 2);
    
     

    %scatter([p1_xs], [p1_ys], 2*radius, p1_labels, 'filled');


    %% Matched nuclei are in hI (hitInd)
    imagesc(J);
    hold on;
    % patch_size
    p_size = patch_size;
    id = 0;
    w = 0;
    % sample all or just a percentage
    for i = sort(randsample(length(hI), round(percentage_samples*length(hI)/100)))',%1:length(hI),
        if (~isnan(hI(i)))
         id = id + 1;
         
        % find out the midpoint of the one pathologist
        mid_x = p1_midpoints{hI(i)}{1};
        mid_y = p1_midpoints{hI(i)}{2};
        
        
        % Radius of patch
        rad = p1_radii(i);
        % find out if there is a relative size of the patch
        if (patch_size <= 0)
            p_size = round(4*rad);
        end;

        % create filenames for the two corresponding patches
        if (rad>2)
            patch1_filename = strcat(imgname, '_nuclID_', sprintf('%d',id), '_p1_label_', strtrim(sprintf('%d',p1_labels(i))), '_r_', sprintf('%u', round(rad)));
        end;


         % make the patches with two labels and store it
        [rect isStained] = makePatch(I, p1_imgfilename, mid_x, mid_y, p_size, patch_foldername, patch1_filename, id<0);

         % store everything in a table rather than in patches
        if (~isempty(rect))
             w = w+1;
             col = 'b';
        if p1_labels(w)==2
            col = 'r';
        end
        plot(mid_x, mid_y, [col '+']);
        col = 'b';
        if Y_hat_new(w)==2
            col = 'r';
        end
        plot(mid_x, mid_y, [col 'o']);

        end;
        end;
    end;
end;

end